@@ -22,13 +22,13 @@ from yarl import URL
 
 from teslajsonpy.connection import Connection
 from teslajsonpy.const import (
+    AUTH_DOMAIN,
     DRIVING_INTERVAL,
     IDLE_INTERVAL,
     ONLINE_INTERVAL,
     SLEEP_INTERVAL,
     TESLA_PRODUCT_TYPE_ENERGY_SITES,
     TESLA_PRODUCT_TYPE_VEHICLES,
-    TESLA_DEFAULT_ENERGY_SITE_NAME,
 )
 from teslajsonpy.exceptions import should_giveup, RetryLimitError, TeslaException
 from teslajsonpy.homeassistant.battery_sensor import Battery, Range
@@ -254,6 +254,7 @@ class Controller:
         expiration: int = 0,
         update_interval: int = 300,
         enable_websocket: bool = False,
+        auth_domain: str = AUTH_DOMAIN
     ) -> None:
         """Initialize controller.
 
@@ -267,6 +268,7 @@ class Controller:
             update_interval (int, optional): Seconds between allowed updates to the API.  This is to prevent
             being blocked by Tesla. Defaults to 300.
             enable_websocket (bool, optional): Whether to connect with websockets. Defaults to False.
+            auth_domain (str, optional): The authentication domain. Defaults to const.AUTH_DOMAIN
 
         """
         self.__connection = Connection(
@@ -278,6 +280,7 @@ class Controller:
             access_token=access_token,
             refresh_token=refresh_token,
             expiration=expiration,
+            auth_domain=auth_domain
         )
         self.__components = []
         self._update_interval: int = update_interval
@@ -373,7 +376,7 @@ class Controller:
             self.__id_energysiteid_map[energysite["id"]] = energysite_id
             self.__energysiteid_id_map[energysite_id] = energysite["id"]
             self.__energysite_name[energysite_id] = energysite.get(
-                "site_name", TESLA_DEFAULT_ENERGY_SITE_NAME
+                "site_name", f"{energysite_id}"
             )
             self.__energysite_type[energysite_id] = energysite["solar_type"]
             self.__power[energysite_id] = {"solar_power": energysite["solar_power"]}
@@ -871,7 +874,7 @@ class Controller:
             tasks = []
             for vin, online in self.car_online.items():
                 # If specific car_id provided, only update match
-                if (car_vin and car_vin != vin) or (
+                if (car_vin and car_vin != vin) or vin not in self.__lock.keys() or (
                     vin and self.car_state[vin].get("in_service")
                 ):
                     continue
